@@ -381,7 +381,8 @@ class VariableClUpdateOtherRepData(ReadonlyTableVariable):
     def generator(self):
         repNames = self.Get('cl_update_rep_name')
         layman = Layman(self.Get('cl_update_layman_installed'),
-                        self.Get('cl_update_layman_make'))
+                        self.Get('cl_update_layman_make'),
+                        self.Get('cl_update_layman_conf'))
         layman_overlays = layman.get_installed()
         for rpath in self.Get('cl_portdir_overlay'):
             repo_file = path.join(rpath, "profiles/repo_name")
@@ -422,6 +423,12 @@ class VariableClUpdateLaymanMake(Variable):
     # TODO: извлечь из layman.cfg
     value = "/var/lib/layman/make.conf"
 
+class VariableClUpdateLaymanConf(Variable):
+    """
+    Путь до конфигурационного файла репозиториев для layman
+    """
+    value = "/etc/portage/repos.conf/layman.conf"
+
 class VariableClUpdatePretendSet(Variable):
     """
     Запустить предварительную проверку на обновления
